import warnings

import pytest
from django.test import TestCase


TestCase.pytestmark = pytest.mark.django_db(transaction=True, reset_sequences=True)


@pytest.fixture(autouse=True)
def suppress_warnings():
    warnings.simplefilter("error", Warning)
    warnings.filterwarnings(
        "ignore", "name used for saved screenshot does not match file type", UserWarning
    )
    warnings.filterwarnings("ignore", "'grappelli' defines default_app_config")
    warnings.filterwarnings("ignore", "The distutils package")
